import { ICommonFetchClient } from "./types";
declare class CommonFetchClient implements ICommonFetchClient {
    private readonly appInstance;
    private readonly logger;
    private readonly requestUrl;
    private readonly middlewareUrl;
    constructor(appInstance: any, requestUrl?: string, middlewareUrl?: string, isDev?: boolean);
    /**
     * fetch的兼容处理，统一返回最终的JSON数据
     *
     * @param endpointUrl - 请求地址
     * @param fetchOptions - 请求参数
     * @param forceProxy - 是否强制使用代理
     */
    fetchCall(endpointUrl: string, fetchOptions: RequestInit, forceProxy?: boolean): Promise<any>;
    /**
     * 支持自定义处理的fetch的兼容处理，统一返回最终的JSON数据
     *
     * @param apiUrl - 请求地址
     * @param fetchOptions - 请求参数
     * @param customHandler - 自定义处理器
     */
    /**
     * 同时兼容浏览器和思源宿主环境的fetch API
     *
     * @param apiUrl - 端点
     * @param fetchOptions - 请求参数
     * @param middlewareUrl - 可选，当环境不支持时候，必传
     * @param forceProxy - 可选，是否强制使用代理
     */
    private fetchRequest;
    /**
     * fetch的兼容处理，统一返回最终的JSON数据
     * @param apiUrl 请求地址
     * @param fetchOptions 请求参数
     * @param middlewareUrl - 可选，当环境不支持时候，必传
     * @param forceProxy - 可选，是否强制使用代理
     */
    private doFetch;
    /**
     * 同时兼容浏览器和思源宿主环境的fetch API，支持浏览器跨域
     * @param apiUrl - 请求地址
     * @param fetchOptions - 请求参数
     * @param middlewareUrl - 可选，当环境不支持时候，必传
     * @param forceProxy - 可选，强制使用代理
     */
    private fetchEntry;
    private safeParseBodyJson;
    /**
     * 解析CORS返回数据
     * @param corsjson cors数据
     * @protected
     */
    private parseCORSBody;
}
export default CommonFetchClient;
